/*
     This file is part of anastasis-gtk.
     Copyright (C) 2020 Anastasis SARL

     Anastasis is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 3, or (at your
     option) any later version.

     Anastasis is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with Anastasis; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
*/
/**
 * @file src/anastasis/anastasis-gtk_handle-policy-selection-changed.c
 * @brief
 * @author Christian Grothoff
 */
#include <gnunet/gnunet_util_lib.h>
#include "anastasis-gtk_helper.h"
#include "anastasis-gtk_action.h"
#include "anastasis-gtk_attributes.h"
#include "anastasis-gtk_handle-identity-changed.h"
#include "anastasis-gtk_rows.h"
#include <jansson.h>

/**
 * Callback invoked if the policy selection changed.
 *
 * @param selection the selection of the secret list
 * @param pspec unused
 * @param user_data user data set when the signal handler was connected.
 */
void
anastasis_gtk_secret_selection_treeselection_changed_cb (
  GtkSingleSelection *selection,
  GParamSpec *pspec,
  gpointer user_data)
{
  (void) pspec;
  (void) user_data;
  if (NULL != AG_selected (selection))
  {
    AG_enable_next ();
  }
  else
  {
    AG_insensitive ("anastasis_gtk_main_window_forward_button");
  }
}
